AttributeKind

Enum AttributeKind 

pub enum AttributeKind {
    Inner,
    Outer,
}
Describes whether an attribute is written as #![...] or #[...].

Variants



Inner

Inner attributes appear inside an item: #![...].



Outer

Outer attributes decorate an item from the outside: #[...].

Implementations

Source

impl AttributeKind

pub const fn is_inner(self) -> bool

Returns true when the attribute is an inner attribute.

Examples
use whitaker_common::attributes::AttributeKind;

assert!(AttributeKind::Inner.is_inner());
assert!(!AttributeKind::Outer.is_inner());
pub const fn is_outer(self) -> bool

Returns true when the attribute is an outer attribute.

Examples
use whitaker_common::attributes::AttributeKind;

assert!(AttributeKind::Outer.is_outer());
assert!(!AttributeKind::Inner.is_outer());