pub type AttributePath = SimplePath;Expand description
Structured representation of an attribute path such as tokio::test.
Aliased Type
pub struct AttributePath { /* private fields */ }pub type AttributePath = SimplePath;Structured representation of an attribute path such as tokio::test.
pub struct AttributePath { /* private fields */ }