pub struct LineSegment { /* private fields */ }Expand description
Describes a constant contribution spanning an inclusive set of one-based line numbers.
Implementations
Sourceimpl LineSegment
impl LineSegment
Sourcepub fn new(
start_line: usize,
end_line: usize,
value: f64,
) -> Result<Self, SegmentError>
pub fn new( start_line: usize, end_line: usize, value: f64, ) -> Result<Self, SegmentError>
Creates a new line segment.
Line numbers are one-based and ranges are inclusive.
Examples
use whitaker_common::complexity_signal::LineSegment;
let segment = LineSegment::new(3, 5, 1.25).expect("segment should be valid");
assert_eq!(segment.start_line(), 3);
assert_eq!(segment.end_line(), 5);Sourcepub const fn start_line(self) -> usize
pub const fn start_line(self) -> usize
Returns the first line covered by the segment (inclusive).