pub struct MethodProfileBuilder { /* private fields */ }Expand description
Mutable builder for MethodProfile.
This follows the existing builder pattern used elsewhere in common and
keeps callers away from constructors with too many arguments.
Examples
use whitaker_common::decomposition_advice::MethodProfileBuilder;
let mut builder = MethodProfileBuilder::new("write_cache");
builder
.record_external_domain("std::fs")
.record_local_type("PathBuf");
let profile = builder.build();
assert_eq!(profile.external_domains().iter().next().map(String::as_str), Some("std::fs"));Implementations
Sourceimpl MethodProfileBuilder
impl MethodProfileBuilder
Sourcepub fn new(name: impl Into<String>) -> Self
pub fn new(name: impl Into<String>) -> Self
Creates an empty builder for the given method name.
Sourcepub fn record_accessed_field(
&mut self,
field_name: impl Into<String>,
) -> &mut Self
pub fn record_accessed_field( &mut self, field_name: impl Into<String>, ) -> &mut Self
Records an accessed field.
Sourcepub fn record_signature_type(
&mut self,
type_name: impl Into<String>,
) -> &mut Self
pub fn record_signature_type( &mut self, type_name: impl Into<String>, ) -> &mut Self
Records a signature type.
Sourcepub fn record_local_type(&mut self, type_name: impl Into<String>) -> &mut Self
pub fn record_local_type(&mut self, type_name: impl Into<String>) -> &mut Self
Records a local-variable type.
Sourcepub fn record_external_domain(&mut self, domain: impl Into<String>) -> &mut Self
pub fn record_external_domain(&mut self, domain: impl Into<String>) -> &mut Self
Records an external domain.
Sourcepub fn build(self) -> MethodProfile
pub fn build(self) -> MethodProfile
Builds the immutable profile.