Utilities for working with source locations and spans.
Structs
- Source
Location - Represents a location in source code using one-based line and column numbers.
- Source
Span - Represents a span of source code.
Enums
- Span
Error - Errors produced when constructing spans.
Functions
- span_
line_ count - Calculates the number of lines covered by the span (inclusive).
- span_
to_ lines - Converts a span into the inclusive range of line numbers it covers.