MethodVectorAlgebraReport

Struct MethodVectorAlgebraReport 

pub struct MethodVectorAlgebraReport { /* private fields */ }
Observable runtime vector-algebra results for two methods.

Examples

use whitaker_common::test_support::decomposition::{MethodInput, method_vector_algebra, profile};

let left = profile(MethodInput {
    name: "parse_tokens",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});
let right = profile(MethodInput {
    name: "parse_nodes",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});

let report = method_vector_algebra(&left, &right);
assert_eq!(report.left_dot_right(), report.right_dot_left());
assert!(report.left_norm_squared() > 0);

Implementations

Source

impl MethodVectorAlgebraReport

pub fn left_dot_right(self) -> u64

Returns the result of MethodVectorAlgebraReport::left_dot_right.

This is the dot product of the left and right method vectors.

use whitaker_common::test_support::decomposition::{MethodInput, method_vector_algebra, profile};

let left = profile(MethodInput {
    name: "parse_tokens",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});
let right = profile(MethodInput {
    name: "parse_nodes",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});

let report = method_vector_algebra(&left, &right);
assert_eq!(report.left_dot_right(), 40);
pub fn right_dot_left(self) -> u64

Returns the result of MethodVectorAlgebraReport::right_dot_left.

This is the dot product of the right and left method vectors.

use whitaker_common::test_support::decomposition::{MethodInput, method_vector_algebra, profile};

let left = profile(MethodInput {
    name: "parse_tokens",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});
let right = profile(MethodInput {
    name: "parse_nodes",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});

let report = method_vector_algebra(&left, &right);
assert_eq!(report.right_dot_left(), 40);
pub fn left_norm_squared(self) -> u64

Returns the result of MethodVectorAlgebraReport::left_norm_squared.

This is the squared L2 norm of the left method vector.

use whitaker_common::test_support::decomposition::{MethodInput, method_vector_algebra, profile};

let left = profile(MethodInput {
    name: "parse_tokens",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});
let right = profile(MethodInput {
    name: "parse_nodes",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});

let report = method_vector_algebra(&left, &right);
assert_eq!(report.left_norm_squared(), 44);
pub fn right_norm_squared(self) -> u64

Returns the result of MethodVectorAlgebraReport::right_norm_squared.

This is the squared L2 norm of the right method vector.

use whitaker_common::test_support::decomposition::{MethodInput, method_vector_algebra, profile};

let left = profile(MethodInput {
    name: "parse_tokens",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});
let right = profile(MethodInput {
    name: "parse_nodes",
    fields: &["grammar"],
    signature_types: &[],
    local_types: &[],
    domains: &[],
});

let report = method_vector_algebra(&left, &right);
assert_eq!(report.right_norm_squared(), 44);